[vlc-commits] fs: clean up vlc_dup() documentation

Rémi Denis-Courmont git at videolan.org
Sun Nov 29 14:55:32 CET 2020


vlc | branch: master | Rémi Denis-Courmont <remi at remlab.net> | Sun Nov 29 11:44:17 2020 +0200| [4c75d5a4aec1e17f596b06bc8710424d340f141f] | committer: Rémi Denis-Courmont

fs: clean up vlc_dup() documentation

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=4c75d5a4aec1e17f596b06bc8710424d340f141f
---

 include/vlc_fs.h | 12 ++++++++----
 1 file changed, 8 insertions(+), 4 deletions(-)

diff --git a/include/vlc_fs.h b/include/vlc_fs.h
index f3f50ea431..4a50288be0 100644
--- a/include/vlc_fs.h
+++ b/include/vlc_fs.h
@@ -100,11 +100,15 @@ VLC_API int vlc_openat(int fd, const char *filename, int flags, ...) VLC_USED;
 VLC_API int vlc_mkstemp( char * );
 
 /**
  * Duplicates a file descriptor. The new file descriptor has the close-on-exec
  * descriptor flag preset.
  * @return a new file descriptor, -1 (see errno)
  */
-VLC_API int vlc_dup(int) VLC_USED;
+VLC_API int vlc_dup(int oldfd) VLC_USED;
 
 /**
  * Creates a pipe (see "man pipe" for further reference). The new file
@@ -100,11 +100,15 @@ VLC_API int vlc_openat(int fd, const char *filename, int flags, ...) VLC_USED;
 
 /**
- * Duplicates a file descriptor. The new file descriptor has the close-on-exec
- * descriptor flag preset.
- * @return a new file descriptor, -1 (see errno)
+ * Duplicates a file descriptor.
+ *
+ * @param oldfd file descriptor to duplicate
+ *
+ * @note Contrary to standard dup(), the new file descriptor has the
+ * close-on-exec descriptor flag preset.
+ * @return a new file descriptor, -1 (see @c errno)
  */



More information about the vlc-commits mailing list